@@ -45,14 +45,21 @@ from modin.pandas.test.utils import (
     int_arg_values,
     eval_general,
     create_test_dfs,
+    default_to_pandas_ignore_string,
 )
 from modin.config import NPartitions
+from modin.test.test_utils import warns_that_defaulting_to_pandas
 
 NPartitions.put(4)
 
 # Force matplotlib to not use any Xwindows backend.
 matplotlib.use("Agg")
 
+# Our configuration in pytest.ini requires that we explicitly catch all
+# instances of defaulting to pandas, but some test modules, like this one,
+# have too many such instances.
+pytestmark = pytest.mark.filterwarnings(default_to_pandas_ignore_string)
+
 
 def eval_insert(modin_df, pandas_df, **kwargs):
     if "col" in kwargs and "column" not in kwargs:
@@ -403,15 +410,6 @@ def test_append(data):
             modin_df.append(list(modin_df.iloc[-1]))
     else:
         modin_result = modin_df.append(list(modin_df.iloc[-1]))
-        # Pandas has bug where sort=False is ignored
-        # (https://github.com/pandas-dev/pandas/issues/35092), but Modin
-        # now does the right thing, so for now manually sort to workaround
-        # this. Once the Pandas bug is fixed and Modin upgrades to that
-        # Pandas release, this sort will cause the test to fail, and the
-        # next three lines should be deleted.
-        if get_current_execution() != "BaseOnPython":
-            assert list(modin_result.columns) == list(modin_df.columns) + [0]
-            modin_result = modin_result[[0] + sorted(modin_df.columns)]
         df_equals(modin_result, pandas_result)
 
     verify_integrity_values = [True, False]
@@ -634,7 +632,7 @@ def test_drop():
             [0.3, 0.2],
         ],
     )
-    with pytest.warns(UserWarning):
+    with warns_that_defaulting_to_pandas():
         df.drop(index="length", level=1)
 
 
@@ -1292,5 +1290,5 @@ def test___abs__(request, data):
 
 def test___round__():
     data = test_data_values[0]
-    with pytest.warns(UserWarning):
+    with warns_that_defaulting_to_pandas():
         pd.DataFrame(data).__round__()
