@@ -16,11 +16,24 @@ import numpy as np
 import pandas
 import modin.pandas as pd
 
-from .utils import df_equals, test_data_values, test_data_keys, create_test_dfs
+from .utils import (
+    df_equals,
+    test_data_values,
+    test_data_keys,
+    create_test_dfs,
+    default_to_pandas_ignore_string,
+)
 from modin.config import NPartitions
 
 NPartitions.put(4)
 
+# Our configuration in pytest.ini requires that we explicitly catch all
+# instances of defaulting to pandas, but some test modules, like this one,
+# have too many such instances.
+# TODO(https://github.com/modin-project/modin/issues/3655): catch all instances
+# of defaulting to pandas.
+pytestmark = pytest.mark.filterwarnings(default_to_pandas_ignore_string)
+
 
 def create_test_series(vals):
     if isinstance(vals, dict):
